/*
This script file outputs the second stage regression of school/school-year fixed effects on peer characteristics (both the OLS and IV)
The IV uses either the feeder-based instruments or the lagged peer characteristics
This script also outputs the first stage regressions of peer characteristics on instruments.
*/

set more off
set mem 20g

global path = "D:\Dropbox\SCP\"

insheet using "${path}/results/gammaDynamic_fe.txt", comma clear
rename v1 school_fe_norand
keep if _n>23
gen indexobs = _n
save "${path}/results/schoolfe_norand.dta", replace

insheet using "${path}/data/regvar.csv", comma clear
rename v1 school_code_x
rename v2 year
rename v3 elem
rename v4 middle
rename v5 schoolfe
save "${path}/data/regvar.dta", replace

foreach year in 04 05 06 07{
insheet using "${path}/data/offenses`year'.txt", delimiter(" ") clear
drop randsid v6 offenses randsid
rename school_code susp
rename suspension_days off
rename year randsid

gen offenses = real(off)
replace offenses=0 if offenses==. 

gen suspension_days = real(susp)
replace suspension_days=0 if suspension_days==. 
save "${path}/data/offenses`year'.dta", replace

insheet using "${path}/data/feederRand`year'.csv", comma clear
drop v1 v3
rename v2 year
rename v4 randsid
rename v5 feederelem
rename v6 feedermiddle
rename v7 feederhigh

save "${path}/data/fp`year'2.dta", replace

insheet using "${path}/data/obsData`year'.csv", comma clear
rename v1 randsid 
rename v2 school_code_x 
rename v3 grade 
rename v4 clunchcode 
rename v5 cracecode 
rename v6 raceOther 
rename v7 MHI 
rename v8 MHHV 
rename v9 V2_y 
rename v10 movingInd 
rename v11 repeatInd 
rename v12 magnetAppInd 
rename v13 overSub 
rename v14 everGiftedInd 
rename v15 everSpecEdInd 
rename v16 school_code_y

merge 1:1 randsid using  "${path}/data/fp`year'2.dta" 
drop if _merge==2
drop _merge

merge 1:1 randsid using "${path}/data/offenses`year'.dta"
drop if _merge==2
drop _merge

gen constant = 1

gen feederschool = feederelem
replace feederschool = feedermiddle if (grade>=6)

rename V2_y ind_ability

foreach i in clunchcode cracecode ind_ability offenses suspension_days{
	bysort school_code_x: egen meanActual_`i' = mean(`i')
	bysort feederschool: egen meanAssigned_`i' = mean(`i')
}

foreach i in constant{
	bysort school_code_x: egen enrollActual_`i' = total(`i')
	bysort feederschool: egen enrollAssigned_`i' = total(`i')
}


preserve
bysort feederschool: gen count_obs = _n
keep if count_obs==1
keep feederschool meanAssigned_* enrollAssigned*
rename feederschool school_code_x
save "${path}/data/schoolCharAssigned`year'.dta", replace
restore

preserve
bysort school_code_x: gen count_obs = _n
keep if count_obs==1
keep school_code_x meanActual_* enrollActual*
save "${path}/data/schoolCharActual`year'.dta", replace
restore

clear
u "${path}/data/schoolCharActual`year'.dta", clear
merge 1:1 school_code_x using "${path}/data/schoolCharAssigned`year'.dta" 
drop _merge
save "${path}/data/schoolCharBoth`year'.dta", replace
}

clear
append using "${path}/data/schoolCharBoth04.dta" "${path}/data/schoolCharBoth05.dta" "${path}/data/schoolCharBoth06.dta" "${path}/data/schoolCharBoth07.dta", generate(year)
replace year = year + 2003

gen index= _n

foreach i in clunchcode cracecode ind_ability offenses suspension_days{
	rename meanAssigned_`i' Feeder`i'
	rename meanActual_`i' Act`i'
}

sort school_code_x year
foreach i in Actclunchcode Actcracecode Actind_ability Actoffenses Actsuspension_days{
	by school_code_x: gen lag_`i' = `i'[_n-1]
}

tab school_code_x, generate(school_codeInd)

merge 1:1 school_code_x year using "${path}/data/regvar.dta"
keep if _merge==3
drop _merge

/*Merging in estimated school fixed effects from model without random coefficients*/
sort year school_code_x
gen indexobs = _n
merge 1:1 indexobs using "${path}/results/schoolfe_norand.dta"
drop _merge

/*Creating an indicator for whether the school closed in 2005-06*/
gen closed = 0
replace closed=1 if school_code_x==4
replace closed=1 if school_code_x==6
replace closed=1 if school_code_x==8
replace closed=1 if school_code_x==10
replace closed=1 if school_code_x==55
replace closed=1 if school_code_x==12
replace closed=1 if school_code_x==51
replace closed=1 if school_code_x==15
replace closed=1 if school_code_x==70
replace closed=1 if school_code_x==21
replace closed=1 if school_code_x==58
replace closed=1 if school_code_x==22
replace closed=1 if school_code_x==26
replace closed=1 if school_code_x==28
replace closed=1 if school_code_x==13
replace closed=1 if school_code_x==57
replace closed=1 if school_code_x==32
replace closed=1 if school_code_x==38
replace closed=1 if school_code_x==60
replace closed=1 if school_code_x==68
replace closed=1 if school_code_x==41
replace closed=1 if school_code_x==67

/*********Regressions using estimated fixed effects from the model without random coefficients**********/
/*OLS Regression of School/School-Year Level Fixed Effects on Peer Characteristics*/
reghdfe school_fe_norand Actclunchcode Actcracecode Actind_ability Actsuspension_days, absorb(elem middle) vce(robust)
outreg2 Actclunchcode Actcracecode Actind_ability Actoffenses Actsuspension_days using "${path}/results/second_stage_reg.tex", replace tex(pr)

/*IV Regression using Lag-based Peer Characteristics as Instruments*/
reghdfe school_fe_norand (Actclunchcode Actcracecode Actind_ability Actsuspension_days = lag_Actclunchcode lag_Actcracecode lag_Actind_ability lag_Actsuspension_days ) , absorb(elem middle) vce(robust)
outreg2 Actclunchcode Actcracecode Actind_ability Actoffenses Actsuspension_days using "${path}/results/second_stage_reg.tex", append tex(pr)


/*IV Regression using Feeder-based Peer Characteristics as Instruments*/
reghdfe school_fe_norand (Actclunchcode Actcracecode Actind_ability Actsuspension_days = Feederclunchcode Feedercracecode Feederind_ability Feedersuspension_days ) , absorb(elem middle) vce(robust)
outreg2 Actclunchcode Actcracecode Actind_ability Actoffenses Actsuspension_days using "${path}/results/second_stage_reg.tex", append tex(pr)

/*IV Regression using Lag-based Peer Characteristics as Instruments*/
reghdfe schoolfe (Actclunchcode Actcracecode Actind_ability Actsuspension_days = lag_Actclunchcode lag_Actcracecode lag_Actind_ability lag_Actsuspension_days ) , absorb(elem middle) vce(robust)
outreg2 Actclunchcode Actcracecode Actind_ability Actoffenses Actsuspension_days using "${path}/results/second_stage_reg.tex", append tex(pr)


/*Lagged First-Stage Regressions: For all years*/
regress Actclunchcode lag_* elem middle, robust
outreg2 lag_* using "${path}/results/first_stage_reg_lag.tex", replace tex(pr) 

regress Actcracecode lag_* elem middle, robust
outreg2 lag_* using "${path}/results/first_stage_reg_lag.tex", append tex(pr) 

regress Actind_ability lag_* elem middle, robust
outreg2 lag_* using "${path}/results/first_stage_reg_lag.tex", append tex(pr) 

regress Actoffenses lag_* elem middle, robust
outreg2 lag_* using "${path}/results/first_stage_reg_lag.tex", append tex(pr) 

regress Actsuspension_days lag_* elem middle, robust
outreg2 lag_* using "${path}/results/first_stage_reg_lag.tex", append tex(pr) 

/*Lagged First-Stage Regressions: Only for the year 2006*/
regress Actclunchcode lag_* elem middle if year==2006, robust
outreg2 lag_* using "${path}/results/first_stage_reg_lag06.tex", replace tex(pr) 

regress Actcracecode lag_*  elem middle if year==2006, robust
outreg2 lag_* using "${path}/results/first_stage_reg_lag06.tex", append tex(pr) 

regress Actind_ability lag_*  elem middle if year==2006, robust
outreg2 lag_* using "${path}/results/first_stage_reg_lag06.tex", append tex(pr) 

regress Actoffenses lag_*  elem middle if year==2006, robust
outreg2 lag_* using "${path}/results/first_stage_reg_lag06.tex", append tex(pr) 

regress Actsuspension_days lag_* elem middle if year==2006, robust
outreg2 lag_* using "${path}/results/first_stage_reg_lag06.tex", append tex(pr) 

/*********Regressions using estimated fixed effects from the model with random coefficients**********/
/*IV Regression using Feeder-based Peer Characteristics as Instruments*/
reghdfe schoolfe (Actclunchcode Actcracecode Actind_ability Actsuspension_days = Feederclunchcode Feedercracecode Feederind_ability Feedersuspension_days ) , absorb(elem middle) vce(robust)
outreg2 Actclunchcode Actcracecode Actind_ability Actoffenses Actsuspension_days using "${path}/results/second_stage_reg.tex", append tex(pr)

/*Feeder First-Stage Regressions: For all years*/
regress Actclunchcode Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days elem middle, robust
outreg2 Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days using "${path}/results/first_stage_reg.tex", replace tex(pr) 

regress Actcracecode Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days elem middle, robust
outreg2 Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days using "${path}/results/first_stage_reg.tex", append tex(pr) 

regress Actind_ability Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days elem middle, robust
outreg2 Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days using "${path}/results/first_stage_reg.tex", append tex(pr) 

regress Actoffenses Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days elem middle, robust
outreg2 Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days using "${path}/results/first_stage_reg.tex", append tex(pr) 

regress Actsuspension_days Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days elem middle, robust
outreg2 Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days using "${path}/results/first_stage_reg.tex", append tex(pr) 

/*Feeder First-Stage Regressions: Only for the year 2006*/
regress Actclunchcode Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days elem middle if year==2006, robust
outreg2 Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days using "${path}/results/first_stage_reg06.tex", replace tex(pr) 

regress Actcracecode Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days elem middle if year==2006, robust
outreg2 Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days using "${path}/results/first_stage_reg06.tex", append tex(pr) 

regress Actind_ability Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days elem middle if year==2006, robust
outreg2 Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days using "${path}/results/first_stage_reg06.tex", append tex(pr) 

regress Actoffenses Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days elem middle if year==2006, robust
outreg2 Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days using "${path}/results/first_stage_reg06.tex", append tex(pr) 

regress Actsuspension_days Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days elem middle if year==2006, robust
outreg2 Feederclunchcode Feedercracecode Feederind_ability Feederoffenses Feedersuspension_days using "${path}/results/first_stage_reg06.tex", append tex(pr) 

